This patch adds support for adding flags to imported mails by appending a
string given as third parameter to the mail filename.
This enables you to import mail as read by using something like
  safecat ~/Maildir/tmp ~/Maildir/cur :2,S
from procmail or whereever you plan to call safecat from.
(The S meens "Seen" in the Maildir filename specification)

diff -ur safecat-1.13/safecat.1 safecat-1.13.new/safecat.1
--- safecat-1.13/safecat.1	2004-08-17 03:27:58.000000000 +0200
+++ safecat-1.13.new/safecat.1	2010-10-25 14:56:11.000000000 +0200
@@ -6,6 +6,7 @@
 .B safecat 
 .I tempdir
 .I destdir
+.I [suffix]
 
 .SH "INTRODUCTION"
 .I safecat
diff -ur safecat-1.13/safecat.c safecat-1.13.new/safecat.c
--- safecat-1.13/safecat.c	2004-08-17 03:14:34.000000000 +0200
+++ safecat-1.13.new/safecat.c	2010-10-25 19:20:30.000000000 +0200
@@ -24,6 +24,7 @@
 #include <fcntl.h>
 #include <signal.h>
 #include <unistd.h>
+#include <stdlib.h>
 
 /* Support for large files (on Linux systems, if the appropriate
    compile-time flag is used. */
@@ -40,6 +41,7 @@
 int main(int argc, char *argv[]) {
   char *tempdir  = NULL;
   char *destdir  = NULL;
+  char *suffix   = "";
   int   outfd    = 0;
   stralloc dstpath = {0};
   stralloc outfile = {0};
@@ -47,16 +49,19 @@
   struct stat filestat;
   unsigned int count = 0;
 
-  /* Check that we were called with the correct number of arguments. */
-  if(argc != 3) {
-    strerr_die2x(100, "safecat: usage: ","safecat <tempdir> <destdir>");
+  /* Check that we were called with the correct number of arguments, then scan
+   * for arguments. */
+  switch (argc) {
+  case 4:
+    suffix  = argv[3];
+  case 3:
+    tempdir = argv[1];
+    destdir = argv[2];
+    break;
+  default:
+    strerr_die2x(100, "safecat: usage: ","safecat <tempdir> <destdir> [<suffix>]");
   }
 
-  /* Scan the command line arguments, to get the temp directory
-     and destination directory names. */
-  tempdir = argv[1];
-  destdir = argv[2];
-
   /* Declare a handler for SIGALRM so we can time out. */
   set_handler(SIGALRM, alarm_handler);
 
@@ -67,7 +72,7 @@
   /* Step 2:  Stat the temporary file.  Wait for ENOENT as a response. */
   for(count=1;;count++) {
     /* Get the temporary filename to use now for dumping data. */
-    mk_tempfile(&outfile);
+    mk_tempfile(&outfile, suffix);
     if (!stralloc_cats(&outpath,tempdir)) die_nomem();
     if (!stralloc_append(&outpath, "/")) die_nomem();
     if (!stralloc_cat(&outpath,&outfile)) die_nomem();
diff -ur safecat-1.13/tempfile.c safecat-1.13.new/tempfile.c
--- safecat-1.13/tempfile.c	2003-07-01 16:03:01.000000000 +0200
+++ safecat-1.13.new/tempfile.c	2010-10-25 19:19:54.000000000 +0200
@@ -12,7 +12,7 @@
 void die_nomem() { strerr_die2x(111,"safecat: fatal: ","out of memory"); }
 
 /* ****************************************************************** */
-void mk_tempfile(stralloc *tmpf) {
+void mk_tempfile(stralloc *tmpf, char *suffix) {
   char host[256];
   char secbuf[11];
   char atto[TAIA_FMTFRAC];
@@ -44,6 +44,7 @@
   if (!stralloc_append(tmpf, ".")) die_nomem();
   get_hostname(host,sizeof(host));
   if (!stralloc_cats(tmpf, host)) die_nomem();
+  if (!stralloc_cats(tmpf, suffix)) die_nomem();
   if (!stralloc_0(tmpf)) die_nomem();
 }
 /* ****************************************************************** */
diff -ur safecat-1.13/tempfile.h safecat-1.13.new/tempfile.h
--- safecat-1.13/tempfile.h	2000-02-29 05:10:12.000000000 +0100
+++ safecat-1.13.new/tempfile.h	2010-10-25 19:22:03.000000000 +0200
@@ -2,4 +2,4 @@
 
 /* Create a temporary file, using a timestamp, PID, and the hostname. */
 #include "stralloc.h"
-void mk_tempfile(stralloc *tmpf);
+void mk_tempfile(stralloc *tmpf, char *suffix);
